<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array(

  	'LBL_MODULE_NAME'				=> 'Projekte',
  	'LBL_MODULE_TITLE'				=> 'Projekte',
    'LBL_NEW_PROJECT'				=> 'Neues Projekt',
    'LBL_PROJECTS'					=> 'Projekte',
    'LBL_PROJECT'					=> 'Projekt',
	'projectname'					=> 'Projektname',
    'projects'						=> 'Projekte',
    'project'						=> 'Projekt',
    //added this to translate the module name in the main app menu
    'Project'						=> 'Projekte',
    //
    'SINGLE_Project' => 'Projekt',
    'LBL_CUSTOM_INFORMATION' => 'zusätzliche Information',
    'LBL_PROJECT_INFORMATION' => 'Projektinformation',
    'LBL_DESCRIPTION_INFORMATION' => 'Beschreibung',
  
    'projectid' => 'Projekt ID',  
    'Project ID'=>'Projekt ID',
    'Assigned To' => 'zuständig',
    'Start Date' => 'Startdatum',
    'Target End Date' => 'angestrebtes Endedatum',
    'Actual End Date' => 'aktuelles Endedatum',
    'Status'=>'Status',
    'Type'=>'Typ',
    'Target Budget'=>'angestrebtes Budget',
    'Project Url'=>'Url',
    'Priority'=>'Priorität',
    'Progress'=>'Fortschritt',
    'Related To' => 'bezogen auf',
    'administrative' => 'administrativ',
    'operative' => 'operativ',
    'other' => 'andere',
    'low' => 'gering',
    'normal' => 'normal',
    'high' => 'hoch',
    'prospecting' => 'in Vorbereitung',
    'in progress' => 'in Bearbeitung',
    'initiated' => 'Initialisiert',
    'on hold' => 'angehalten',
    'archived' => 'archiviert',
    'completed' => 'abgeschlossen',
    'delivered' => 'geliefert',
    'Created Time' => 'erstellt',
    'Modified Time' => 'bearbeitet',
    'Description' => 'Beschreibung',
    'description' => 'Beschreibung',
    '--none--' => '--ohne--',
    'Project Name' => 'Projektname',
    'LBL_RELATED_PROJECT_TASKS' => 'Projektaufgaben',
    'LBL_RELATED_PROJECT_MILESTONES' => 'Projektmeilensteine',
    
    'Charts' => 'Charts',
	'LBL_PROGRESS_CHART' => 'Progress Chart',
	'Project No' => 'Projektnr.',
	
	'Project Milestones' => 'Projektmeilensteine',
	'Project Tasks' => 'Projektaufgaben',
	'Project Team' => 'Projekt Team',
	'Project ID' => 'Projekt ID',
);

?>